powered by
Converts partial eta squared (\(\eta_p^2\)) to Cohen's f using the standard definition in Cohen (1988).
peta2_to_cohensf(peta2)
A numeric vector of Cohen's f values.
A numeric vector of partial eta squared values. Each value must be within the range of 0 to 1.
The conversion is defined as: $$f = \sqrt{\eta_p^2 / (1 - \eta_p^2)}$$
This follows from the inverse relationship: $$\eta_p^2 = \frac{f^2}{1 + f^2}$$
Cohen, J. (1988). Statistical power analysis for the behavioral sciences (2nd ed.). Hillsdale, NJ: Lawrence Erlbaum Associates.
cohensf_to_peta2
# Convert a single partial eta squared value peta2_to_cohensf(0.06) # Convert multiple values peta2_to_cohensf(c(0.01, 0.06, 0.14))
Run the code above in your browser using DataLab